pub(super) fn renders_percentage(node: Option<&SpellDescriptionNode>) -> boolExpand description
Whether the text right after an expression block starts the percentage it renders.
pub(super) fn renders_percentage(node: Option<&SpellDescriptionNode>) -> boolWhether the text right after an expression block starts the percentage it renders.